/*

$Id: bosh.h,v 1.40 2008/12/19 16:51:45 alexsisson Exp $

(C) Copyright 2004-2008 Alex Sisson (alexsisson@gmail.com)

This file is part of bosh.

bosh is free software; you can redistribute it and/or modify
under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

bosh is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with bosh; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


#ifndef BOSH_H_INCLUDED
#define BOSH_H_INCLUDED

#include <stdio.h>
#include <sys/types.h>

#include "list.h"

#define BOSH_WIDTH_DEFAULT            32
#define BOSH_PIPE_USLEEP            1000
#define BOSH_INPUTWAIT_USLEEP     100000

/* bosh interface modes */
#define BOSH_MODE_NORMAL   0
#define BOSH_MODE_READSTR  1

/* bosh action types */
#define BOSH_ACTION_COMMAND  0x01
#define BOSH_ACTION_BOSH     0x02

/* bosh action output destinations */
#define BOSH_ACTION_OUTPUT_NONE       ' '
#define BOSH_ACTION_OUTPUT_OVERWRITE  '.'
#define BOSH_ACTION_OUTPUT_ADVANCE    '>'
#define BOSH_ACTION_OUTPUT_ENDCURSES  '!'
#define BOSH_ACTION_OUTPUT_NEWWINDOW  /* not decided  */

/* bosh special actions - must be greater than 37 */
#define BOSH_ACTION_SPECIAL_SHOWCONF  40

typedef struct bosh_action_t {
  int   dest;
  char *command;
  char *prompt;
} ACTION;


/* BOSH structure, defines a pane in the bosh window. */
typedef struct bosh_t {

  /* process */
  char *command;
  int exit;

  int fd;          /* main fd to read from (eg stdout of child process) */
  int fderr;       /* stderr of child process */
  pid_t childpid;
  char script[16]; /* made with mkstmp so always fixed length */

  /* interface */
  LIST *buf;
  int width;
  int offset;
  int cursor;
  int line;
  char *pipe;

  /* options */
  int   autorefresh;
  int   cursorsize;
  int   cursormovement;
  char *multilineseperator;
  char *preaction;
  int   refresh;
  int   searchwrap;
  int   header;
  int   footer;

  /* actions */
  ACTION action[37];

} BOSH;



extern BOSH   *bosh;          /* pointer to current BOSH struct (only 1 ever used at the moment!) */
extern LIST   *boshlist;      /* linked list for BOSH structs */
extern int    boshlistpos;
extern char   *conf;
extern char   *confpath;
extern char   *shell;

extern char   *dollarbosh;
extern char   *dollarboshparam;
extern char   dollarbosherrfile[16];

#ifdef LOG
extern FILE *bosh_log;
#endif



BOSH *bosh_new();
int bosh_free(BOSH *b);
int bosh_redraw();





#endif
